pub struct CreateDirectChatDialog {
list_box: TemplateChild<ListBox>,
search_entry: TemplateChild<SearchEntry>,
stack: TemplateChild<Stack>,
error_page: TemplateChild<StatusPage>,
session: WeakRef<Session>,
}Fields
list_box: TemplateChild<ListBox>search_entry: TemplateChild<SearchEntry>stack: TemplateChild<Stack>error_page: TemplateChild<StatusPage>session: WeakRef<Session>The current session.
Implementations
Sourceimpl CreateDirectChatDialog
impl CreateDirectChatDialog
Sourcefn register_type()
fn register_type()
Registers the type only once.
Sourceimpl CreateDirectChatDialog
impl CreateDirectChatDialog
Sourcefn set_session(&self, session: Option<&Session>)
fn set_session(&self, session: Option<&Session>)
Set the current session.
Sourcefn set_visible_page(&self, page: CreateDirectChatDialogPage)
fn set_visible_page(&self, page: CreateDirectChatDialogPage)
Set the visible page of the dialog.
Sourcefn update_view(&self, user_list: &DirectChatUserList)
fn update_view(&self, user_list: &DirectChatUserList)
Update the view for the current state of the user list.
Sourcefn show_error(&self, message: &str)
fn show_error(&self, message: &str)
Show the given error message.
Sourceasync fn create_direct_chat(&self, row: &ListBoxRow)
async fn create_direct_chat(&self, row: &ListBoxRow)
Create a direct chat with the user from the given row.